@@ -24,12 +24,13 @@
 
 import sys
 import os.path
+import googletrans
 from colored import fore, style
 from googletrans import Translator
 
 
 TOOL = 'subtrs'
-VERSION = 1.1
+VERSION = 1.3
 
 
 class Subtitles:
@@ -39,7 +40,7 @@ class Subtitles:
         '''Initialization'''
         self.flags = flags
         self.file = args[0]
-        self.dest = args[1]
+        self.dest = args[1].split(',')
         self.ext = self.file[-4:]
         self.f = ''
         self.color()
@@ -69,25 +70,27 @@ class Subtitles:
 
     def write_new_subs(self):
         '''Write the new subtitle file'''
-        self.Exceptions_dest_lang()
-        self.read_subs()
-        cap_file = self.file.split('/')[-1]
-        new_captions = f'{cap_file[:-4]}_{self.dest}{self.ext}'
-        with open(new_captions, 'w') as new_subs:
-            for line in self.f:
-                if line and not line[0].isdigit():
-                    if len(line) > 1 and '--silent' not in self.flags:
-                        print(f'{self.IN_COLOR}<<{self.RESET_COLOR} {line}')
-                    line = self.translate(line)
-                    if len(line) > 1 and '--silent' not in self.flags:
-                        print(f'{self.OUT_COLOR}>> '
-                              f'{self.TRS_COLOR}{line}{self.RESET_COLOR}')
-                new_subs.write(line)
-        self.created_file(new_captions)
+        for lang in self.dest:
+            self.Exceptions_dest_lang(lang)
+            self.read_subs()
+            cap_file = self.file.split('/')[-1]
+            new_captions = f'{cap_file[:-4]}_{lang}{self.ext}'
+            with open(new_captions, 'w') as new_subs:
+                for line in self.f:
+                    if line and not line[0].isdigit():
+                        if len(line) > 1 and '--silent' not in self.flags:
+                            print(f'{self.IN_COLOR}<<{self.RESET_COLOR}'
+                                  f' {line}')
+                        line = self.translate(line, lang)
+                        if len(line) > 1 and '--silent' not in self.flags:
+                            print(f'{self.OUT_COLOR}>> '
+                                  f'{self.TRS_COLOR}{line}{self.RESET_COLOR}')
+                    new_subs.write(line)
+            self.created_file(new_captions)
 
-    def translate(self, line):
+    def translate(self, line, lang):
         '''Translate line per line'''
-        return self.translator.translate(line, dest=self.dest).text + '\n'
+        return self.translator.translate(line, dest=lang).text + '\n'
 
     def created_file(self, file):
         '''Message when the file finished'''
@@ -100,28 +103,29 @@ class Subtitles:
         '''Check if the file exists'''
         return os.path.exists(file)
 
-    def Exceptions_dest_lang(self):
+    def Exceptions_dest_lang(self, lang):
         '''Check for destination language'''
         try:
-            self.translator.translate('Video', dest=self.dest).text
+            self.translator.translate('Video', dest=lang).text
         except ValueError as Err:
-            print(f'Error: {Err} "{self.dest}"')
+            print(f'Error: {Err} "{lang}"')
             raise SystemExit(1)
 
 
 def usage(status):
     '''CLI help menu'''
-    args = ['Usage: subtrs [subtitles_file] [destination lang]',
+    args = ['Usage: subtrs [subtitles_file] [destination languages]',
             ' ',
             '       Simple tool that trlanslates video subtitles',
             ' ',
             '       Support subtitles files [*.sbv, *.vtt, *.srt]',
-            '       Destination language [en, de, ru] etc.',
+            '       Destination languages [en,de,ru] etc.',
             ' ',
-            '       --color    Show translate text language with colour.',
-            '       --silent   Silent method, without viewing.',
-            '       --version  Show the version and exit.',
-            '       --help     Show this message and exit.',
+            '       --color      Show translate text language with colour.',
+            '       --languages  Show all supported languages.',
+            '       --silent     Silent method, without viewing.',
+            '       --version    Show the version and exit.',
+            '       --help       Show this message and exit.',
             ]
     for opt in args:
         print(opt)
@@ -143,18 +147,29 @@ def args_flags(args):
 def check_usage(args):
     '''Checking usage'''
     file_ext = ['.sbv', '.vtt', '.srt']
+
     if args == []:
         usage(status=0)
+
     # Show the version and exit
-    if args[0] == '--version':
+    if args[0] == '--version' and len(args) == 1:
         print(f'{TOOL} version {VERSION}')
         raise SystemExit(0)
+
     # Show help menu and exit
-    if args[0] == '--help':
+    if args[0] == '--help' and len(args) == 1:
         usage(status=0)
+
+    # Show all suported languages
+    if args[0] == '--languages' and len(args) == 1:
+        for key, value in googletrans.LANGUAGES.items():
+            print(key, value)
+        raise SystemExit()
+
     # Check for subtitle extention file
     if args[0][-4:] not in file_ext:
         usage(status=1)
+
     # Check for max options
     if len(args) < 2 or len(args) > 2:
         usage(status=1)
